@@ -50,6 +50,11 @@ install_miniconda <- function(path = miniconda_path(),
   url <- miniconda_installer_url()
   installer <- miniconda_installer_download(url)
 
+  if (force) {
+    # miniconda installer '-u' (update) flag frequently does not work, errors.
+    miniconda_uninstall(path)
+  }
+
   # run the installer
   miniconda_installer_run(installer, update, path)
 
@@ -118,7 +123,16 @@ install_miniconda_preflight <- function(path, force) {
     )
 
     stopf(fmt, pretty_path(path))
+  }
 
+  if (length(list.files(path))) {
+    fmt <- paste(
+      "Directory %s is not empty.",
+      "- Existing files will be permanently deleted during installation.",
+      sep = "\n"
+    )
+
+    stopf(fmt, pretty_path(path))
   }
 
   # ok to proceed
