@@ -30,7 +30,7 @@ freely, subject to the following restrictions:
 #ifndef _TINYTHREAD_H_
 #define _TINYTHREAD_H_
 
-extern "C" void Rf_error(const char* fmt, ...);
+#include <R_ext/Error.h>  // for Rf_error()
 
 /// @file
 /// @mainpage TinyThread++ API Reference
